@@ -67,7 +67,7 @@ main (int argc, char **argv)
 			"no-stretch", 0, 0, G_OPTION_ARG_NONE, &no_stretch,
 			N_("Do not try to stretch images on screen"), NULL
 		},
-		{ NULL }
+		{ NULL, 0, 0, G_OPTION_ARG_NONE, NULL, NULL, NULL }
 	};
 
 	bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
@@ -93,8 +93,9 @@ main (int argc, char **argv)
 	g_set_prgname ("slideshow");
 
 	window = gs_theme_window_new ();
-	g_signal_connect (G_OBJECT (window), "delete-event",
-	                  G_CALLBACK (gtk_main_quit), NULL);
+	g_signal_connect (window, "delete-event",
+	                  G_CALLBACK (gtk_main_quit),
+	                  NULL);
 
 	engine = g_object_new (GSTE_TYPE_SLIDESHOW, NULL);
 
