@@ -106,7 +106,7 @@ typedef struct
 	char    *connection;
 	guint32  cookie;
 	guint32  foreign_cookie;
-	GTimeVal since;
+	gint64   since;
 } GSListenerRefEntry;
 
 enum
@@ -363,7 +363,7 @@ gs_listener_set_throttle (GSListener *listener,
 	{
 		gs_debug ("Changing throttle status: %d", throttled);
 
-		listener->priv->throttled = throttled;
+		listener->priv->throttled = (throttled != FALSE);
 
 		g_signal_emit (listener, signals [THROTTLE_CHANGED], 0, throttled);
 	}
@@ -390,7 +390,7 @@ static gboolean
 listener_set_session_idle_internal (GSListener *listener,
                                     gboolean    idle)
 {
-	listener->priv->session_idle = idle;
+	listener->priv->session_idle = (idle != FALSE);
 
 	if (idle)
 	{
@@ -408,7 +408,7 @@ static gboolean
 listener_set_active_internal (GSListener *listener,
                               gboolean    active)
 {
-	listener->priv->active = active;
+	listener->priv->active = (active != FALSE);
 
 	/* if idle not in sync with active, change it */
 	if (listener->priv->session_idle != active)
@@ -496,7 +496,7 @@ gs_listener_set_session_idle (GSListener *listener,
 		}
 	}
 
-	listener->priv->session_idle = idle;
+	listener->priv->session_idle = (idle != FALSE);
 	res = listener_check_activation (listener);
 
 	/* if activation fails then don't set idle */
@@ -541,7 +541,7 @@ gs_listener_set_activation_enabled (GSListener *listener,
 
 	if (listener->priv->activation_enabled != enabled)
 	{
-		listener->priv->activation_enabled = enabled;
+		listener->priv->activation_enabled = (enabled != FALSE);
 	}
 }
 
@@ -830,10 +830,12 @@ accumulate_ref_entry (gpointer            key,
                       GSListenerRefEntry *entry,
                       DBusMessageIter    *iter)
 {
+	GDateTime *dt;
 	char *description;
 	char *time;
 
-	time = g_time_val_to_iso8601 (&entry->since);
+	dt = g_date_time_new_from_unix_utc (entry->since);
+	time = g_date_time_format_iso8601 (dt);
 
 	description = g_strdup_printf ("Application=\"%s\"; Since=\"%s\"; Reason=\"%s\";",
 	                               entry->application,
@@ -844,6 +846,7 @@ accumulate_ref_entry (gpointer            key,
 
 	g_free (description);
 	g_free (time);
+	g_date_time_unref (dt);
 }
 
 static DBusHandlerResult
@@ -906,7 +909,7 @@ listener_add_ck_ref_entry (GSListener     *listener,
 	entry->cookie = listener_generate_unique_key (listener, entry_type);
 	entry->application = g_strdup ("ConsoleKit");
 	entry->reason = g_strdup ("Session is not active");
-	g_get_current_time (&entry->since);
+	entry->since = g_get_real_time () / G_USEC_PER_SEC;
 
 	/* takes ownership of entry */
 	listener_add_ref_entry (listener, entry_type, entry);
@@ -973,7 +976,7 @@ listener_dbus_add_ref_entry (GSListener     *listener,
 	entry->cookie = listener_generate_unique_key (listener, entry_type);
 	entry->application = g_strdup (application);
 	entry->reason = g_strdup (reason);
-	g_get_current_time (&entry->since);
+	entry->since = g_get_real_time () / G_USEC_PER_SEC;
 
 	listener_add_ref_entry (listener, entry_type, entry);
 
@@ -2208,7 +2211,6 @@ gs_listener_class_init (GSListenerClass *klass)
 	                                         G_PARAM_READWRITE));
 }
 
-
 static gboolean
 screensaver_is_running (DBusConnection *connection)
 {
