@@ -62,7 +62,6 @@
 #define KEY_LOCK_DIALOG_T_FMT "lock-dialog-time-format"
 #define KEY_LOCK_DIALOG_D_FMT "lock-dialog-date-format"
 
-
 #define MDM_FLEXISERVER_COMMAND "mdmflexiserver"
 #define MDM_FLEXISERVER_ARGS    "--startnew Standard"
 
@@ -137,7 +136,6 @@ struct _ResponseData
 	gint response_id;
 };
 
-
 enum
 {
     RESPONSE,
@@ -456,7 +454,6 @@ dialog_timed_out (gpointer user_data)
 	return FALSE;
 }
 
-
 static void
 capslock_update (GSLockPlug *plug,
                  gboolean    is_on)
@@ -687,7 +684,6 @@ gs_lock_plug_run (GSLockPlug *plug)
 	return ri.response_id;
 }
 
-
 static cairo_surface_t *
 surface_from_pixbuf (GdkPixbuf *pixbuf)
 {
@@ -872,7 +868,6 @@ frame_pixbuf (GdkPixbuf *source)
 						   h);
 	rowstride = gdk_pixbuf_get_rowstride (dest);
 
-
 	data = g_new0 (guint8, h * rowstride);
 
 	surface = cairo_image_surface_create_for_data (data,
@@ -1056,7 +1051,6 @@ gs_lock_plug_show (GtkWidget *widget)
 
 	gs_profile_end ("parent");
 
-
 	if (plug->priv->auth_face_image)
 	{
 		set_face_image (plug);
@@ -1729,8 +1723,8 @@ expand_string (const char *text)
 	GString       *str;
 	const char    *p;
 	char          *username;
-	int            i;
-	int            n_chars;
+	glong          i;
+	glong          n_chars;
 	struct utsname name;
 
 	str = g_string_sized_new (strlen (text));
