@@ -89,11 +89,11 @@ remove_watchdog_timer (GSWatcher *watcher)
 
 static void
 add_watchdog_timer (GSWatcher *watcher,
-                    glong      timeout)
+                    guint      timeout)
 {
 	watcher->priv->watchdog_timer_id = g_timeout_add (timeout,
-	                                   (GSourceFunc)watchdog_timer,
-	                                   watcher);
+	                                                  (GSourceFunc)watchdog_timer,
+	                                                  watcher);
 }
 
 static void
@@ -203,7 +203,7 @@ _gs_watcher_set_session_idle_notice (GSWatcher *watcher,
 		{
 			gs_debug ("Changing idle notice state: %d", in_effect);
 
-			watcher->priv->idle_notice = in_effect;
+			watcher->priv->idle_notice = (in_effect != FALSE);
 		}
 		else
 		{
@@ -230,7 +230,7 @@ _gs_watcher_set_session_idle (GSWatcher *watcher,
 		{
 			gs_debug ("Changing idle state: %d", is_idle);
 
-			watcher->priv->idle = is_idle;
+			watcher->priv->idle = (is_idle != FALSE);
 		}
 		else
 		{
@@ -269,7 +269,7 @@ _gs_watcher_set_active_internal (GSWatcher *watcher,
 		/* reset state */
 		_gs_watcher_reset_state (watcher);
 
-		watcher->priv->active = active;
+		watcher->priv->active = (active != FALSE);
 	}
 
 	return TRUE;
@@ -309,7 +309,7 @@ gs_watcher_set_enabled (GSWatcher *watcher,
 	{
 		gboolean is_active = gs_watcher_get_active (watcher);
 
-		watcher->priv->enabled = enabled;
+		watcher->priv->enabled = (enabled != FALSE);
 
 		/* if we are disabling the watcher and we are
 		   active shut it down */
@@ -642,7 +642,6 @@ disable_builtin_screensaver (GSWatcher *watcher,
 	}
 }
 
-
 /* This timer goes off every few minutes, whether the user is idle or not,
    to try and clean up anything that has gone wrong.
 
