@@ -93,10 +93,10 @@ static GSettings      *session_settings = NULL;
 static GSettings      *lockdown_settings = NULL;
 static MateDesktopThumbnailFactory *thumb_factory = NULL;
 
-static gint32
+static gdouble
 config_get_activate_delay (gboolean *is_writable)
 {
-	gint32 delay;
+	gint delay;
 
 	if (is_writable)
 	{
@@ -104,14 +104,12 @@ config_get_activate_delay (gboolean *is_writable)
 		               KEY_IDLE_DELAY);
 	}
 
-	delay = g_settings_get_int (session_settings, KEY_IDLE_DELAY);
-
-	if (delay < 1)
+	if ((delay = g_settings_get_int (session_settings, KEY_IDLE_DELAY)) < 1)
 	{
-		delay = 1;
+		return 1.0;
 	}
 
-	return delay;
+	return (gdouble) delay;
 }
 
 static void
@@ -722,7 +720,7 @@ setup_treeview (GtkWidget *tree,
 
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree));
 	gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
-	g_signal_connect (G_OBJECT (select), "changed",
+	g_signal_connect (select, "changed",
 	                  G_CALLBACK (tree_selection_changed_cb),
 	                  preview);
 
@@ -1072,7 +1070,7 @@ format_value_callback_time (GtkScale *scale,
 	if (value == 0)
 		return g_strdup_printf (_("Never"));
 
-	return time_to_string_text (value * 60.0);
+	return time_to_string_text ((long) (value * 60.0));
 }
 
 static void
@@ -1154,7 +1152,7 @@ ui_set_enabled (gboolean enabled)
 }
 
 static void
-ui_set_delay (int delay)
+ui_set_delay (gdouble delay)
 {
 	GtkWidget *widget;
 
@@ -1201,7 +1199,7 @@ key_changed_cb (GSettings *settings, const gchar *key, gpointer data)
 			int delay;
 
 			delay = g_settings_get_int (settings, key);
-                        ui_set_delay (delay);
+			ui_set_delay ((gdouble) delay);
 
 	}
 	else
@@ -1424,12 +1422,10 @@ spawn_command_line_on_display_sync (GdkDisplay  *display,
 	return retval;
 }
 
-
 static GdkVisual *
 get_best_visual_for_display (GdkDisplay *display)
 {
 	GdkScreen    *screen;
-	char         *command;
 	char         *std_output;
 	int           exit_status;
 	GError       *error;
@@ -1441,19 +1437,18 @@ get_best_visual_for_display (GdkDisplay *display)
 	visual = NULL;
 	screen = gdk_display_get_default_screen (display);
 
-	command = g_build_filename (LIBEXECDIR, "mate-screensaver-gl-helper", NULL);
-
 	error = NULL;
 	std_output = NULL;
 	res = spawn_command_line_on_display_sync (display,
-	        command,
+	        MATE_SCREENSAVER_GL_HELPER_PATH,
 	        &std_output,
 	        NULL,
 	        &exit_status,
 	        &error);
 	if (! res)
 	{
-		gs_debug ("Could not run command '%s': %s", command, error->message);
+		gs_debug ("Could not run command '%s': %s",
+		          MATE_SCREENSAVER_GL_HELPER_PATH, error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -1474,12 +1469,10 @@ get_best_visual_for_display (GdkDisplay *display)
 	}
 out:
 	g_free (std_output);
-	g_free (command);
 
 	return visual;
 }
 
-
 static void
 widget_set_best_visual (GtkWidget *widget)
 {
